"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mocklify = exports.MocklifyInstance = void 0;
var limiter_1 = require("./limiter");
var operator_1 = require("./operator");
var MocklifyInstance = /** @class */ (function () {
    function MocklifyInstance() {
        this.data = [];
    }
    MocklifyInstance.prototype.add = function (targetLength, items, predicate) {
        var matchingItems = predicate ? items.filter(predicate) : items;
        var matchingItemCount = matchingItems.length;
        if (matchingItemCount === 0) {
            throw new Error('Cannot add items to mock data set because no items matched the predicate');
        }
        // Start with all items that matched the predicate
        var dataToAdd = matchingItems;
        // Pad it out so that it is at least as long as the target length, repeating if necessary
        if (matchingItemCount < targetLength) {
            var countNeeded = targetLength - matchingItemCount;
            var timesToAdd = Math.ceil(countNeeded / matchingItemCount);
            for (var i = 0; i < timesToAdd; i++) {
                dataToAdd = dataToAdd.concat(matchingItems);
            }
        }
        // Trim down to the target length if there are excess items
        dataToAdd = dataToAdd.slice(0, targetLength);
        // Finally, add all of the new items to the internal state
        this.data = this.data.concat(dataToAdd);
        // Return a chainable instance
        return this;
    };
    MocklifyInstance.prototype.addAll = function (items, predicate) {
        var matchingItems = predicate ? items.filter(predicate) : items;
        this.data = this.data.concat(matchingItems);
        return this;
    };
    MocklifyInstance.prototype.addOne = function (item) {
        if (item !== null && item !== undefined) {
            this.data = this.data.concat(item);
        }
        return this;
    };
    MocklifyInstance.prototype.generate = function (count, factory) {
        var newItems = [];
        for (var i = 0; i < count; i++) {
            newItems.push(factory(i));
        }
        this.data = this.data.concat(newItems);
        return this;
    };
    MocklifyInstance.prototype.generatePartial = function (count, factory) {
        var newItems = [];
        for (var i = 0; i < count; i++) {
            newItems.push(factory(i));
        }
        this.data = this.data.concat(newItems);
        return this;
    };
    MocklifyInstance.prototype.filter = function (predicate) {
        this.data = this.data.filter(predicate);
        return this;
    };
    MocklifyInstance.prototype.transform = function () {
        var operators = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            operators[_i] = arguments[_i];
        }
        this.data = (0, operator_1.applyOperators)(this.data, operators, limiter_1.DEFAULT_LIMITER);
        return this;
    };
    MocklifyInstance.prototype.get = function (count) {
        return count > 0 ? this.data.slice(0, count) : [];
    };
    MocklifyInstance.prototype.getSlice = function (start, end) {
        return this.data.slice(start, end);
    };
    MocklifyInstance.prototype.getAll = function () {
        return this.data;
    };
    MocklifyInstance.prototype.getFirst = function () {
        return this.data[0];
    };
    MocklifyInstance.prototype.getLast = function () {
        var lastItem = this.data.slice(-1)[0];
        return lastItem;
    };
    MocklifyInstance.prototype.getOne = function (predicate) {
        return this.data.find(predicate);
    };
    MocklifyInstance.prototype.getWhere = function (predicate) {
        return this.data.filter(predicate);
    };
    MocklifyInstance.prototype.getRandom = function (count) {
        var results = [];
        var availableItems = __spreadArray([], this.data, true);
        for (var i = 0; i < count && availableItems.length > 0; i++) {
            var randomIndex = this.getRandomIntBetween(0, availableItems.length - 1);
            var randomItem = availableItems.splice(randomIndex, 1)[0];
            results.push(randomItem);
        }
        return results;
    };
    MocklifyInstance.prototype.getRandomOne = function () {
        var _a;
        return (_a = this.getRandom(1)) === null || _a === void 0 ? void 0 : _a[0];
    };
    MocklifyInstance.prototype.getShuffled = function () {
        return this.getRandom(this.data.length);
    };
    MocklifyInstance.prototype.getRandomIntBetween = function (min, max) {
        return Math.floor(Math.random() * (max - min + 1)) + min;
    };
    return MocklifyInstance;
}());
exports.MocklifyInstance = MocklifyInstance;
function mocklify() {
    return new MocklifyInstance();
}
exports.mocklify = mocklify;
