"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var main_1 = require("../main");
var test_data_1 = require("./test-data/test-data");
describe('add()', function () {
    it('adds first n items if no predicate is specified', function () {
        var results = (0, main_1.mocklify)()
            .add(test_data_1.MOCK_USERS.length, test_data_1.MOCK_USERS)
            .getAll();
        expect(results.length).toBe(test_data_1.MOCK_USERS.length);
        expect(results).toEqual(test_data_1.MOCK_USERS);
    });
    it('throws an error if no items match the predicate', function () {
        var whereNameDoesntExist = function (user) { return user.firstName === 'Nonexistant user'; };
        expect(function () {
            (0, main_1.mocklify)()
                .add(50, test_data_1.MOCK_USERS, whereNameDoesntExist)
                .getAll();
        }).toThrow();
    });
    it('pads the results to the target length if the number of matches is less than the target length', function () {
        var whereNameIsPotter = function (user) { return user.lastName === 'Potter'; };
        var results = (0, main_1.mocklify)()
            .add(50, test_data_1.MOCK_USERS, whereNameIsPotter)
            .getAll();
        expect(results.length).toBe(50);
        expect(results.every(function (user) { return user.lastName === 'Potter'; }));
    });
    it('should repeat the matched items to reach the target length when padding', function () {
        var results = (0, main_1.mocklify)()
            .add(12, test_data_1.MOCK_USERS, function (user) { return user.lastName === 'Potter'; })
            .getAll();
        expect(results.length).toBe(12);
        expect(results[0]).toEqual(results[6]);
        expect(results[1]).toEqual(results[7]);
        expect(results[2]).toEqual(results[8]);
        expect(results[3]).toEqual(results[9]);
        expect(results[4]).toEqual(results[10]);
        expect(results[5]).toEqual(results[11]);
    });
    it('trims the results down if the number of matches exceeds the target length', function () {
        var results = (0, main_1.mocklify)()
            .add(1, test_data_1.MOCK_USERS)
            .getAll();
        expect(results.length).toBe(1);
    });
});
