"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var main_1 = require("../main");
var operators_1 = require("../operators");
var test_data_1 = require("./test-data/test-data");
describe('generate()', function () {
    it('[generate] should generate n items using a specified factory function', function () {
        var users = test_data_1.MOCK_USER_FACTORY;
        var results = (0, main_1.mocklify)()
            .generate(3, users)
            .getAll();
        expect(results.length).toBe(3);
        expect(results).toEqual([
            (0, test_data_1.MOCK_USER_FACTORY)(0),
            (0, test_data_1.MOCK_USER_FACTORY)(1),
            (0, test_data_1.MOCK_USER_FACTORY)(2)
        ]);
    });
    it('[generate] should have no effect if the number passed in is less than 1', function () {
        var users = test_data_1.MOCK_USER_FACTORY;
        var resultsZero = (0, main_1.mocklify)()
            .generate(0, users)
            .getAll();
        var resultsNegative = (0, main_1.mocklify)()
            .generate(-1, users)
            .getAll();
        expect(resultsZero).toEqual([]);
        expect(resultsNegative).toEqual([]);
    });
    it('[generatePartial] should allow generation of n partial items, using a specified factory function', function () {
        var users = test_data_1.PARTIAL_MOCK_USER_FACTORY;
        var results = (0, main_1.mocklify)()
            .generatePartial(3, users)
            .transform((0, operators_1.modify)(function (user, index) { return user.firstName = "Generated User ".concat(index + 1); }))
            .getAll();
        expect(results.length).toBe(3);
        expect(results).toEqual([
            Object.assign({}, (0, test_data_1.PARTIAL_MOCK_USER_FACTORY)(0), { firstName: "Generated User 1" }),
            Object.assign({}, (0, test_data_1.PARTIAL_MOCK_USER_FACTORY)(1), { firstName: "Generated User 2" }),
            Object.assign({}, (0, test_data_1.PARTIAL_MOCK_USER_FACTORY)(2), { firstName: "Generated User 3" }),
        ]);
    });
});
