"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var main_1 = require("../main");
var operators_1 = require("../operators");
var test_data_1 = require("./test-data/test-data");
describe('terminators', function () {
    it('[getAll] gets all the updated results', function () {
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getAll();
        expect(results.length).toEqual(test_data_1.MOCK_USERS.length);
    });
    it('[getFirst] gets the first item of the updated results', function () {
        var result = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getFirst();
        expect(result).toEqual(test_data_1.MOCK_USERS[0]);
    });
    it('[getLast] gets the last item of the updated results', function () {
        var result = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getLast();
        var lastIndex = test_data_1.MOCK_USERS.length - 1;
        expect(result).toEqual(test_data_1.MOCK_USERS[lastIndex]);
    });
    it('[get] gets the first n results', function () {
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .get(10);
        var firstTenUsers = test_data_1.MOCK_USERS.slice(0, 10);
        expect(results).toEqual(firstTenUsers);
        expect(results.length).toBe(10);
    });
    it('[get] if the number is greater than the length of the results should return all it can but not pad or dupe', function () {
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .get(test_data_1.MOCK_USERS.length + 100);
        expect(results).toEqual(test_data_1.MOCK_USERS);
    });
    it('[get] if number is negative you get an empty array', function () {
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .get(-5);
        expect(results).toEqual([]);
    });
    it('[get] if number is a float it is floored', function () {
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .get(5.2);
        var results2 = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .get(5.9);
        expect(results.length).toBe(5);
        expect(results2.length).toBe(5);
    });
    it('[getSlice] you can get a slice of the results', function () {
        var resultsFirstFive = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getSlice(0, 5);
        var resultsSecondAndThird = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getSlice(1, 3);
        var resultsLast = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getSlice(-1);
        var resultsAllButFirstAndLast = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getSlice(1, -1);
        expect(resultsFirstFive).toEqual(test_data_1.MOCK_USERS.slice(0, 5));
        expect(resultsFirstFive.length).toBe(5);
        expect(resultsSecondAndThird).toEqual(test_data_1.MOCK_USERS.slice(1, 3));
        expect(resultsSecondAndThird.length).toBe(2);
        expect(resultsLast).toEqual(test_data_1.MOCK_USERS.slice(-1));
        expect(resultsLast.length).toBe(1);
        expect(resultsAllButFirstAndLast).toEqual(test_data_1.MOCK_USERS.slice(1, -1));
        expect(resultsAllButFirstAndLast.length).toBe(test_data_1.MOCK_USERS.length - 2);
    });
    it('[getOne] return first item that matches the predicate', function () {
        var whereNameIsPotter = function (user) { return user.lastName === 'Potter'; };
        var result = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getOne(whereNameIsPotter);
        expect(result).not.toBeUndefined();
        expect(result === null || result === void 0 ? void 0 : result.firstName).toEqual('Harry');
    });
    it('[getOne] returns undefined if the predicate is not matched', function () {
        var whereNameDoesNotExist = function (user) { return user.lastName === 'Non Existent Character'; };
        var result = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getOne(whereNameDoesNotExist);
        expect(result).toBeUndefined();
    });
    it('[getWhere] gets all the updated results that match the predicate', function () {
        var whereNameIsPotter = function (user) { return user.lastName === 'Potter'; };
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getWhere(whereNameIsPotter);
        expect(results.length).toBe(6);
    });
    it('[getWhere] gets all the updated results that match the predicate', function () {
        var whereNameIsHazzer = function (user) { return user.firstName === 'Hazzer'; };
        var results = (0, main_1.mocklify)()
            .add(1, test_data_1.MOCK_USERS)
            .transform((0, operators_1.override)({ firstName: 'Hazzer' }))
            .getWhere(whereNameIsHazzer);
        expect(results.length).toBe(1);
    });
    it('[getRandom] gets a random selection of results', function () {
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getRandom(5);
        expect(results.length).toBe(5);
    });
    it('[getRandom] gets a random selection of results, up to the length of the original array (shuffle the items)', function () {
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getRandom(test_data_1.MOCK_USERS.length + 100);
        expect(results.length).toBe(test_data_1.MOCK_USERS.length);
    });
    it('[getRandom] returns an empty array if you ask for less than one random items', function () {
        var resultsZero = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getRandom(0);
        var resultsNegative = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getRandom(-1);
        expect(resultsZero).toEqual([]);
        expect(resultsNegative).toEqual([]);
    });
    it('[getRandomOne] gets a single result, chosen at random', function () {
        var result = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getRandomOne();
        expect(result).toBeTruthy();
        expect(result).toEqual(expect.any(Object));
    });
    it('[getRandomOne] returns undefined if there are no items in the data set', function () {
        var result = (0, main_1.mocklify)()
            .getRandomOne();
        expect(result).toBeUndefined();
    });
    it('[getShuffled] returns the same items shuffled into a random order', function () {
        var results = (0, main_1.mocklify)()
            .addAll(test_data_1.MOCK_USERS)
            .getShuffled();
        expect(results.length).toBe(test_data_1.MOCK_USERS.length);
        expect(results).not.toEqual(test_data_1.MOCK_USERS);
    });
});
